@@ -159,8 +159,8 @@ class dyagram:
 
                     executor.submit(self.__discover_lldp_neighbors, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_lldp_neighbors")
-                    # executor.submit(self.discover_routes, device)
-                    # self.log.info(f"DEVICE: {device} - Submitted for discover_routes")
+                    executor.submit(self.discover_routes, device)
+                    self.log.info(f"DEVICE: {device} - Submitted for discover_routes")
                     executor.submit(self.discover_dynamic_routing_neighbors, device)
                     self.log.info(f"DEVICE: {device} - Submitted for discover_dynamic_routing_neighbors")
 
@@ -392,7 +392,7 @@ class dyagram:
         return None
 
     def discover_eigrp_neighbors(self, device):
-
+        #time.sleep(5) #FIXME: IF I DON'T PUT THIS HERE THERE IS AN EXCEPTION THROWN THAT I CAN'T CATCH
         try:
             self.log.info(f"DEVICE: {device} - RESTCONF : Discovering EIGRP Neighbors - START")
             discovered = self.discover_eigrp_neighbors_restconf()
